AppcuesOptions class
A set of options that can be configured when initializing the Appcues plugin.
Constructors
Properties
- activityStorageMaxAge ↔ int?
-
The duration, in seconds, that an analytics request can be stored on
the local device and retried later, in the case of the device network
connection being unavailable.
getter/setter pair
- activityStorageMaxSize ↔ int?
-
The number of analytics requests that can be stored on the local device
and retried later, in the case of the device network connection being
unavailable.
getter/setter pair
- apiHost ↔ String?
-
The API host path to be used for Appcues requests.
getter/setter pair
- enableUniversalLinks ↔ bool?
-
Applies to iOS only. When enabled, the iOS SDK will pass potential
universal links back to the host application AppDelegate function
application(_:continue:restorationHandler:). The host application is responsible for returning true if the link was handled as a deep link into a screen in the app, or false if not. By default, universal link support is disabled for Flutter applications, since the default FlutterAppDelegate template always returns a true value fromapplication(_:continue:restorationHandler:)and blocks subsequent link handling.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- logging ↔ bool?
-
Determines whether logging is enabled.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionTimeout ↔ int?
-
The timeout value, in seconds, used to determine if a new session is
started upon the application returning to the foreground.
getter/setter pair
- settingsHost ↔ String?
-
The settings host path to be used for Appcues settings requests.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited